<?php

namespace Ssd\Ssd\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ssd\Ssd\Models\Lufuno;

class LufunoPolicy
{


    /**
     * Determine if the given user can view the lufuno.
     *
     * @param UserPolicyInterface $authUser
     * @param Lufuno $lufuno
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Lufuno $lufuno)
    {
        if ($authUser->canDo('ssd.lufuno.view') && $authUser->isAdmin()) {
            return true;
        }

        return $lufuno->user_id == user_id() && $lufuno->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lufuno.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('ssd.lufuno.create');
    }

    /**
     * Determine if the given user can update the given lufuno.
     *
     * @param UserPolicyInterface $authUser
     * @param Lufuno $lufuno
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Lufuno $lufuno)
    {
        if ($authUser->canDo('ssd.lufuno.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $lufuno->user_id == user_id() && $lufuno->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lufuno.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Lufuno $lufuno)
    {
        return $lufuno->user_id == user_id() && $lufuno->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lufuno.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Lufuno $lufuno)
    {
        if ($authUser->canDo('ssd.lufuno.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lufuno.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Lufuno $lufuno)
    {
        if ($authUser->canDo('ssd.lufuno.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
